==> terraform-0.2.11.tgz: terraform-0.2.11/src/GuiDialogPreview.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _GUI_DIALOG_PREVIEW_H
#define _GUI_DIALOG_PREVIEW_H


#include <gtk--.h>
#include <gtk/gtk.h>
#include "GuiBufferedDrawingArea.h"


class GuiDialogPreview : public Gtk_Dialog
	{
	public: 
					GuiDialogPreview (char *winTitle, char *frameTitle, 
							  int tableX, int tableY);
					~GuiDialogPreview (); 

	protected:
		void			insertPreview ();
		void			clearPreview ();
		void			setupVBox ();
		virtual void		fillVBox ();
		virtual void		fillActionArea ();
		virtual void		buildDialogWindow ();
		virtual void 		buttonCallbackOK ();
		virtual void 		buttonCallbackApply ();
		virtual void 		buttonCallbackCancel ();
		virtual void		checkboxCallbackPreview ();
		virtual gint 		delete_event_impl (GdkEventAny *);

		int			d_size, 
					d_frameBorder;
		Gtk_VBox		d_vBoxPreview;
		Gtk_Button		d_btnOK,
					d_btnApply,
					d_btnCancel;
		Gtk_CheckButton		d_cbUsePreview;
		Gtk_Frame		*d_baseFrame,
					*d_previewFrame,
					*d_previewGroupFrame;
		Gtk_Preview		*d_preview;
		GuiBufferedDrawingArea	*d_drawArea;
		Gtk_Table		*d_table;
		char			*d_winTitle, 
					*d_frameTitle;
	};


#endif // _GUI_DIALOG_PREVIEW_H

==> terraform-0.3.0.tgz: terraform-0.3.0/src/GuiDialogPreview.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _GUI_DIALOG_PREVIEW_H
#define _GUI_DIALOG_PREVIEW_H


#include <gtk--.h>
#include <gtk/gtk.h>
#include "GuiBufferedDrawingArea.h"


class GuiDialogPreview : public Gtk_Dialog
	{
	public: 
					GuiDialogPreview (char *winTitle, char *frameTitle, 
							  int tableX, int tableY);
					~GuiDialogPreview (); 
		void			clearPreview ();
		virtual void		buildDialogWindow ();
		static void		iterateEvents ();

	protected:
		void			fillActionArea ();
		void			insertPreview ();
		void			setupVBox ();
		virtual void 		buttonCallbackOK ();
		virtual void 		buttonCallbackApply ();
		virtual void 		buttonCallbackCancel ();
		virtual void		checkboxCallbackPreview ();
		virtual gint 		delete_event_impl (GdkEventAny *);
		virtual void		insertOptions ();

		int			d_size, 
					d_frameBorder;
		Gtk_VBox		d_vBoxPreview;
		Gtk_Button		d_btnOK,
					d_btnApply,
					d_btnCancel;
		Gtk_CheckButton		d_cbUsePreview;
		Gtk_Frame		*d_baseFrame,
					*d_previewFrame,
					*d_previewGroupFrame;
		Gtk_Preview		*d_preview;
		GuiBufferedDrawingArea	*d_drawArea;
		Gtk_Table		*d_table;
		char			*d_winTitle, 
					*d_frameTitle;
		bool			d_applyHit;
	};


#endif // _GUI_DIALOG_PREVIEW_H
